@@ -4,7 +4,7 @@ require Mojo::PgX::Cursor::Database;
 
 use Mojo::Base 'Mojo::Pg';
 
-our $VERSION = "0.500001";
+our $VERSION = "0.501000";
 
 sub db {
     my $db = shift->SUPER::db(@_);
@@ -22,7 +22,6 @@ Mojo::PgX::Cursor - Cursor Extension for Mojo::Pg
 
 =head1 SYNOPSIS
 
-    require Mojo::PgX::Cursor;
     my $pg = Mojo::PgX::Cursor->new('postgresql://postgres@/test');
     my $results = $pg->db->cursor('select * from some_big_table');
     while (my $next = $results->hash) {
@@ -32,7 +31,7 @@ Mojo::PgX::Cursor - Cursor Extension for Mojo::Pg
 =head1 DESCRIPTION
 
 L<DBD::Pg> fetches all rows when a statement is executed whereas other drivers
-usually fetch rows using the C<fetch*> methods.  C<Mojo::PgX::Cursor> is an
+usually fetch rows using the C<fetch*> methods.  Mojo::PgX::Cursor is an
 extension to work around this issue using PostgreSQL cursors while providing a
 L<Mojo::Pg>-style API for iteratoring over the results; see
 L<Mojo::PgX::Cursor::Results> for details.
@@ -74,7 +73,7 @@ time.
 =head1 CONTRIBUTING
 
 If you would like to submit bug reports, feature requests, questions, etc. you
-should create an issue on the <GitHub Issue
+should create an issue on the L<GitHub Issue
 Tracker|https://github.com/nnutter/mojo-pgx-cursor/issues> for this module.
 
 =head1 REFERENCES
