@@ -7,7 +7,7 @@ use Time::HiRes qw(time);
 
 use Mojo::Base -base;
 
-has [qw(seconds_blocked fetch)];
+has [qw(seconds_blocked fetch_count)];
 
 sub array {
   my $self = shift->_fetch;
@@ -73,7 +73,7 @@ sub _load_next {
   my $self = shift;
   $self->{delay} = Mojo::IOLoop->delay(
     sub {
-      $self->cursor->fetch($self->{fetch}, shift->begin);
+      $self->cursor->fetch($self->{fetch_count}, shift->begin);
     },
     sub {
       $self->{next} = $_[2];
@@ -98,20 +98,17 @@ __END__
 
 Mojo::PgX::Cursor::Results
 
-=head1 SYNOPSIS
-
 =head1 DESCRIPTION
 
 L<Mojo::PgX::Cursor::Results> is a container for a L<Mojo::PgX::Cursor::Cursor>
 like L<Mojo::Pg::Results> is for a statement handle.  Therefore it tries to
 mimic the API of L<Mojo::Pg::Results> whereever it makes sense to do do.
 
-L<Mojo::PgX::Cursor::Results> should behave like L<Mojo::Pg::Results> for
-C<array>, C<columns>, C<hash>, and C<expand>.
-
-L<Mojo::PgX::Cursor::Results> does not support C<hashes> or C<arrays> since if
-you wish to use those you should just use C<query> instead.  Also note, C<rows>
-returns the number of rows in the current iteration not the total rows for the query.
+This container should behave like L<Mojo::Pg::Results> for C<array>,
+C<columns>, C<hash>, and C<expand>.  It intentionally does not support
+C<hashes> or C<arrays> since if you wish to use those you should just use
+C<query> instead.  One difference in behavior is C<rows> returns the number of
+rows in the current iteration not the total rows for the query.
 
 =head1 ATTRIBUTES
 
@@ -122,9 +119,9 @@ returns the number of rows in the current iteration not the total rows for the q
 
 The L<Mojo::PgX::Cursor::Cursor> rows are fetched from.
 
-=head2 fetch
+=head2 fetch_count
 
-    $results->fetch(10);
+    $results->fetch_count(10);
 
 The quantity of rows to fetch in each iteration.  Since the next iteration is
 always pre-fetched up to twice this many rows will be in memory at any given
